document.addEventListener('DOMContentLoaded', () => {
    const result = document.getElementById('result');
    const buttons = document.querySelectorAll('button');
    
    let currentNumber = '';
    let firstOperand = null;
    let operator = null;
    let shouldResetScreen = false;
    let lastResult = null;

    // Button highlighting effect
    function highlightButton(button) {
        button.classList.add('active-button');
        setTimeout(() => {
            button.classList.remove('active-button');
        }, 200);
    }

    function formatNumber(number) {
        if (number === 'Error') return number;
        const maxLength = 12;
        const numStr = number.toString();
        
        if (numStr.length > maxLength) {
            if (numStr.includes('e')) {
                return number.toExponential(maxLength - 7);
            }
            if (numStr.includes('.')) {
                return Number(number).toPrecision(maxLength - 2);
            }
            return number.toExponential(maxLength - 7);
        }
        return numStr;
    }

    function updateDisplay(value) {
        result.value = formatNumber(value);
    }

    function clear() {
        currentNumber = '';
        firstOperand = null;
        operator = null;
        lastResult = null;
        updateDisplay('0');
    }

    function handleNumber(number) {
        if (shouldResetScreen) {
            currentNumber = '';
            shouldResetScreen = false;
        }
        
        if (currentNumber.length < 12) {
            if (currentNumber === '0') {
                currentNumber = number;
            } else {
                currentNumber += number;
            }
            updateDisplay(currentNumber);
        }
    }

    function handleDecimal() {
        if (shouldResetScreen) {
            currentNumber = '0';
            shouldResetScreen = false;
        }
        if (!currentNumber.includes('.')) {
            currentNumber = currentNumber || '0';
            currentNumber += '.';
            updateDisplay(currentNumber);
        }
    }

    function handleOperator(nextOperator) {
        const inputValue = parseFloat(currentNumber);

        if (operator && shouldResetScreen) {
            operator = nextOperator;
            return;
        }

        if (firstOperand === null && !currentNumber && lastResult !== null) {
            firstOperand = lastResult;
        } else if (firstOperand === null) {
            firstOperand = inputValue || 0;
        } else if (operator) {
            const result = calculate(firstOperand, inputValue || firstOperand, operator);
            updateDisplay(result);
            firstOperand = result;
            lastResult = result;
        }

        shouldResetScreen = true;
        operator = nextOperator;
    }

    function calculate(first, second, op) {
        let result;
        
        switch (op) {
            case '+':
                result = first + second;
                break;
            case '-':
                result = first - second;
                break;
            case '*':
                result = first * second;
                break;
            case '/':
                result = second === 0 ? 'Error' : first / second;
                break;
            case '%':
                result = (first * second) / 100;
                break;
            default:
                result = second;
        }

        if (result === 'Error') return 'Error';
        if (isNaN(result) || !isFinite(result)) return 'Error';
        
        return result;
    }

    buttons.forEach(button => {
        button.addEventListener('click', (event) => {
            highlightButton(button);
            
            if (button.classList.contains('clear')) {
                clear();
            } else if (button.classList.contains('operator')) {
                if (button.textContent === '=') {
                    if (operator && currentNumber) {
                        const inputValue = parseFloat(currentNumber);
                        const result = calculate(firstOperand, inputValue, operator);
                        updateDisplay(result);
                        lastResult = result;
                        firstOperand = null;
                        operator = null;
                        shouldResetScreen = true;
                    }
                } else {
                    handleOperator(button.textContent);
                }
            } else if (button.textContent === '.') {
                handleDecimal();
            } else {
                handleNumber(button.textContent);
            }
        });
    });

    // Initialize display
    updateDisplay('0');

    // Add keyboard support with highlighting
    document.addEventListener('keydown', (event) => {
        const key = event.key;
        const button = Array.from(buttons).find(btn => {
            if (key >= '0' && key <= '9') return btn.textContent === key;
            if (key === '.') return btn.textContent === '.';
            if (key === '+' || key === '-' || key === '*' || key === '/') return btn.textContent === key;
            if (key === 'Enter' || key === '=') return btn.textContent === '=';
            if (key === 'Escape') return btn.textContent === 'C';
            if (key === '%') return btn.textContent === '%';
            return false;
        });

        if (button) {
            button.click();
            highlightButton(button);
            event.preventDefault();
        }
    });

    // Initialize Three.js scene for hero section
    let scene, camera, renderer;
    let cube;

    function initThreeJS() {
        scene = new THREE.Scene();
        camera = new THREE.PerspectiveCamera(75, window.innerWidth / window.innerHeight, 0.1, 1000);
        renderer = new THREE.WebGLRenderer({ alpha: true });
        
        const container = document.getElementById('hero-canvas');
        renderer.setSize(container.offsetWidth, container.offsetHeight);
        container.appendChild(renderer.domElement);

        // Create animated cube
        const geometry = new THREE.BoxGeometry();
        const material = new THREE.MeshPhongMaterial({ color: 0x3498db });
        cube = new THREE.Mesh(geometry, material);
        scene.add(cube);

        // Add lights
        const light = new THREE.DirectionalLight(0xffffff, 1);
        light.position.set(1, 1, 1);
        scene.add(light);
        
        const ambientLight = new THREE.AmbientLight(0xffffff, 0.5);
        scene.add(ambientLight);

        camera.position.z = 5;
    }

    function animate() {
        requestAnimationFrame(animate);
        
        if (cube) {
            cube.rotation.x += 0.01;
            cube.rotation.y += 0.01;
        }
        
        renderer.render(scene, camera);
    }

    // Handle window resize
    function onWindowResize() {
        const container = document.getElementById('hero-canvas');
        camera.aspect = container.offsetWidth / container.offsetHeight;
        camera.updateProjectionMatrix();
        renderer.setSize(container.offsetWidth, container.offsetHeight);
    }

    // Portfolio filtering
    function initPortfolioFilters() {
        const filterBtns = document.querySelectorAll('.filter-btn');
        const portfolioItems = document.querySelectorAll('.portfolio-item');

        filterBtns.forEach(btn => {
            btn.addEventListener('click', () => {
                // Remove active class from all buttons
                filterBtns.forEach(b => b.classList.remove('active'));
                // Add active class to clicked button
                btn.classList.add('active');

                const filter = btn.getAttribute('data-filter');
                
                portfolioItems.forEach(item => {
                    if (filter === 'all' || item.getAttribute('data-category') === filter) {
                        item.style.display = 'block';
                    } else {
                        item.style.display = 'none';
                    }
                });
            });
        });
    }

    // Smooth scrolling for navigation links
    function initSmoothScroll() {
        document.querySelectorAll('a[href^="#"]').forEach(anchor => {
            anchor.addEventListener('click', function(e) {
                e.preventDefault();
                const target = document.querySelector(this.getAttribute('href'));
                if (target) {
                    target.scrollIntoView({
                        behavior: 'smooth',
                        block: 'start'
                    });
                }
            });
        });
    }

    // Form validation and submission
    function initContactForm() {
        const form = document.getElementById('contact-form');
        if (form) {
            form.addEventListener('submit', async (e) => {
                e.preventDefault();
                
                // Basic form validation
                const name = form.querySelector('input[type="text"]').value;
                const email = form.querySelector('input[type="email"]').value;
                const message = form.querySelector('textarea').value;
                
                if (!name || !email || !message) {
                    alert('Please fill in all fields');
                    return;
                }
                
                // Here you would typically send the form data to your backend
                try {
                    // Simulate form submission
                    await new Promise(resolve => setTimeout(resolve, 1000));
                    alert('Message sent successfully!');
                    form.reset();
                } catch (error) {
                    alert('Error sending message. Please try again.');
                }
            });
        }
    }

    // Scroll animations
    function initScrollAnimations() {
        const sections = document.querySelectorAll('section');
        
        const observer = new IntersectionObserver((entries) => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    entry.target.classList.add('animate');
                }
            });
        }, {
            threshold: 0.1
        });
        
        sections.forEach(section => {
            observer.observe(section);
        });
    }

    // Initialize everything when DOM is loaded
    initThreeJS();
    animate();
    initPortfolioFilters();
    initSmoothScroll();
    initContactForm();
    initScrollAnimations();
    
    window.addEventListener('resize', onWindowResize);

    // Add sample portfolio items
    function addSamplePortfolioItems() {
        const portfolioGrid = document.querySelector('.portfolio-grid');
        
        const sampleItems = [
            {
                category: 'gaming',
                title: 'Game Character Animation',
                image: 'path/to/game-character.jpg'
            },
            {
                category: 'product',
                title: 'Product Visualization',
                image: 'path/to/product.jpg'
            },
            {
                category: 'film',
                title: 'Short Film Animation',
                image: 'path/to/film.jpg'
            }
        ];
        
        sampleItems.forEach(item => {
            const itemElement = document.createElement('div');
            itemElement.className = 'portfolio-item';
            itemElement.setAttribute('data-category', item.category);
            
            itemElement.innerHTML = `
                <img src="${item.image}" alt="${item.title}">
                <div class="portfolio-item-info">
                    <h3>${item.title}</h3>
                    <p>Category: ${item.category}</p>
                </div>
            `;
            
            portfolioGrid.appendChild(itemElement);
        });
    }

    addSamplePortfolioItems();
});
